==> firefox-123.0b6.source.tar.xz: firefox-123.0/devtools/client/inspector/compatibility/test/browser/browser_compatibility_event_selected-node-change.js <==
/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

"use strict";

// Test whether the content of the issue list will be changed when the new node is selected.

const TEST_URI = `
  <style>
  body {
    ruby-align: center;
  }

  .has-issue {
    scrollbar-width: thin;
    user-modify: read-only;
  }

  .no-issue {
    color: black;
  }
  </style>
  <body>
    <div class="has-issue">has issue</div>
    <div class="no-issue">no issue</div>
  </body>
`;

const TEST_DATA_SELECTED = [
  {
    selector: ".has-issue",
    expectedIssues: [
      {
        property: "scrollbar-width",
        url: "https://developer.mozilla.org/docs/Web/CSS/scrollbar-width",
      },
      {
        property: "user-modify",
        url: "https://developer.mozilla.org/docs/Web/CSS/user-modify",
      },
    ],
  },
  {
    selector: ".no-issue",
    expectedIssues: [],
  },
  {
    selector: "body",
    expectedIssues: [
      {
        property: "ruby-align",
        url: "https://developer.mozilla.org/docs/Web/CSS/ruby-align",
      },
    ],
  },
];

const TEST_DATA_ALL = [
  {
    property: "ruby-align",
    url: "https://developer.mozilla.org/docs/Web/CSS/ruby-align",
  },
  {
    property: "scrollbar-width",
    url: "https://developer.mozilla.org/docs/Web/CSS/scrollbar-width",
  },
  {
    property: "user-modify",
    url: "https://developer.mozilla.org/docs/Web/CSS/user-modify",
  },
];

add_task(async function () {
  await addTab("data:text/html;charset=utf-8," + encodeURIComponent(TEST_URI));

  const { allElementsPane, inspector, selectedElementPane } =
    await openCompatibilityView();

  for (const { selector, expectedIssues } of TEST_DATA_SELECTED) {
    info(`Check the issue list for ${selector} node`);
    await selectNode(selector, inspector);
    await assertIssueList(selectedElementPane, expectedIssues);
    info("Check whether the issues on all elements pane are not changed");
    await assertIssueList(allElementsPane, TEST_DATA_ALL);
  }
});

==> firefox-147.0.3.source.tar.xz: firefox-147.0.3/devtools/client/inspector/compatibility/test/browser/browser_compatibility_event_selected-node-change.js <==
/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

"use strict";

// Test whether the content of the issue list will be changed when the new node is selected.

const TEST_URI = `
  <style>
  body {
    overflow-anchor: auto;
  }

  .has-issue {
    scrollbar-color: auto;
    user-modify: read-only;
  }

  .no-issue {
    color: black;
  }
  </style>
  <body>
    <div class="has-issue">has issue</div>
    <div class="no-issue">no issue</div>
  </body>
`;

const TEST_DATA_SELECTED = [
  {
    selector: ".has-issue",
    expectedIssues: [
      {
        property: "scrollbar-color",
        url: "https://developer.mozilla.org/docs/Web/CSS/Reference/Properties/scrollbar-color",
      },
      {
        property: "user-modify",
        url: "https://developer.mozilla.org/docs/Web/CSS/Reference/Properties/user-modify",
      },
    ],
  },
  {
    selector: ".no-issue",
    expectedIssues: [],
  },
  {
    selector: "body",
    expectedIssues: [
      {
        property: "overflow-anchor",
        url: "https://developer.mozilla.org/docs/Web/CSS/Reference/Properties/overflow-anchor",
      },
    ],
  },
];

const TEST_DATA_ALL = [
  {
    property: "overflow-anchor",
    url: "https://developer.mozilla.org/docs/Web/CSS/Reference/Properties/overflow-anchor",
  },
  {
    property: "scrollbar-color",
    url: "https://developer.mozilla.org/docs/Web/CSS/Reference/Properties/scrollbar-color",
  },
  {
    property: "user-modify",
    url: "https://developer.mozilla.org/docs/Web/CSS/Reference/Properties/user-modify",
  },
];

add_task(async function () {
  await addTab("data:text/html;charset=utf-8," + encodeURIComponent(TEST_URI));

  const { allElementsPane, inspector, selectedElementPane } =
    await openCompatibilityView();

  for (const { selector, expectedIssues } of TEST_DATA_SELECTED) {
    info(`Check the issue list for ${selector} node`);
    await selectNode(selector, inspector);
    await assertIssueList(selectedElementPane, expectedIssues);
    info("Check whether the issues on all elements pane are not changed");
    await assertIssueList(allElementsPane, TEST_DATA_ALL);
  }
});
